package api

import (
	"errors"
	"spu3d/db/model"
	"spu3d/db/repo"

	"github.com/gin-gonic/gin"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

type UserInfo struct {
	Id       primitive.ObjectID
	IsSystem bool
	// 是不是自己查询自己
	IsOwner bool
	Scope   string // queenshow spu3d
}

var SystemCategoryUserId = "64b0e7409d7adb3612011fa1"

const IPV6_API = "https://api.vore.top/api/IPv6?v6="
const IPV4_API = "https://api.vore.top/api/IPv4?v4="

type IPVRes struct {
	Msg    string  `json:"msg"`
	IpData *IpArea `json:"ipdata"`
}

type IpArea struct {
	Province string `json:"info1"`
	City     string `json:"info2"`
	District string `json:"info3"`
	Isp      string `json:"isp"`
}

type IpInfo struct {
	Ip string `json:"ip"`
	IPVRes
}

func getUserRole(_ *gin.Context, apictx *ApiSession) ([]string, error) {
	if apictx.User != nil {
		userId, _ := primitive.ObjectIDFromHex(apictx.User.Parent)
		var searchUser model.UserSmaple
		ok, err := repo.RepoSeachDoc(apictx.CreateRepoCtx(), &repo.DocSearchOptions{
			Db:          "usercenter",
			CollectName: "users",
			Query:       repo.Map{"_id": userId},
			Project:     []string{"roles"},
		}, &searchUser)
		if err != nil {
			return nil, errors.New("查询用户失败")
		}
		if !ok {
			return nil, errors.New("没有该用户信息")
		}
		return searchUser.Roles, nil

	} else {
		return nil, errors.New("用户未登录")
	}

}

func isSysUser(roles []string) bool {
	if len(roles) > 0 {
		for _, role := range roles {
			if role == "system" {
				return true
			}
		}
	}
	return false
}
